@@ -1,6 +1,5 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
-#
 # tool/fontawesome.rb: Convert PaymentFont SCSS variables to YAML legend.
 #
 # Copyright September 2017, Jesse Doyle. All rights reserved.
@@ -9,8 +8,8 @@
 
 require_relative 'scss/parser'
 
-PREFIX = /pf-var-(?<key>.+):\s*"\\(?<unicode>.*)";/
-VERSION = /pf-version:\s*"(?<version>.*)"/
+PREFIX = /pf-var-(?<key>.+):\s*"\\(?<unicode>.*)";/.freeze
+VERSION = /pf-version:\s*"(?<version>.*)"/.freeze
 
 puts 'Please enter in the path to the _variables.scss file:'
 path = File.expand_path(gets.chomp)
